# eric7.Plugins.VcsPlugins.vcsMercurial.QueuesExtension

Package implementing the queues extension support interface.

### Modules

HgQueuesDefineGuardsDialog | Module implementing a dialog to define guards for patches.
HgQueuesFoldDialog | Module implementing a dialog to enter data to fold patches.
HgQueuesGuardsSelectionDialog | Module implementing a dialog to select a list of guards.
HgQueuesHeaderDialog | Module implementing a dialog to show the commit message of the current patch.
HgQueuesListAllGuardsDialog | Module implementing a dialog to show all guards for all patches.
HgQueuesListDialog | Module implementing a dialog to show a list of applied and unapplied patches.
HgQueuesListGuardsDialog | Module implementing a dialog to show the guards of a selected patch.
HgQueuesNewPatchDialog | Module implementing a dialog to get the data for a new patch.
HgQueuesQueueManagementDialog | Module implementing a dialog used by the queue management functions.
HgQueuesRenamePatchDialog | Module implementing a dialog to enter the data to rename a patch.
ProjectHelper | Module implementing the queues extension project helper.
queues | Module implementing the queues extension interface.